| chen_ols | R Documentation |
Helper function for Chen & Chen OLS estimation
chen_ols(X_l, Y_l, f_l, X_u, f_u, intercept = TRUE)
X_l |
(matrix): n x p matrix of covariates in the labeled data. |
Y_l |
(vector): n-vector of labeled outcomes. |
f_l |
(vector): n-vector of predictions in the labeled data. |
X_u |
(matrix): N x p matrix of covariates in the unlabeled data. |
f_u |
(vector): N-vector of predictions in the unlabeled data. |
intercept |
(Logical): Do the design matrices include intercept
columns? Default is |
Another look at statistical inference with machine learning-imputed data (Gronsbell et al., 2026) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.48550/arXiv.2411.19908")}
(list): A list containing the following:
(vector): vector of Chen & Chen OLS regression coefficient estimates.
(vector): vector of standard errors of the coefficients.
dat <- simdat(model = "ols")
form <- Y - f ~ X1
X_l <- model.matrix(form, data = dat[dat$set_label == "labeled", ])
Y_l <- dat[dat$set_label == "labeled", all.vars(form)[1]] |>
matrix(ncol = 1)
f_l <- dat[dat$set_label == "labeled", all.vars(form)[2]] |>
matrix(ncol = 1)
X_u <- model.matrix(form, data = dat[dat$set_label == "unlabeled", ])
f_u <- dat[dat$set_label == "unlabeled", all.vars(form)[2]] |>
matrix(ncol = 1)
chen_ols(X_l, Y_l, f_l, X_u, f_u, intercept = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.