log1pexp: Log1p Exponential

View source: R/utils_ppi.R

log1pexpR Documentation

Log1p Exponential

Description

Computes the natural logarithm of 1 plus the exponential of the input, to handle large inputs.

Usage

log1pexp(x)

Arguments

x

(vector): A numeric vector of inputs.

Value

(vector): A numeric vector where each element is the result of log(1 + exp(x)).


ipd documentation built on March 11, 2026, 5:07 p.m.