Learn R Programming

ipd (version 0.4.0)

pdc_poisson: PDC Poisson

Description

Helper function for PDC Poisson regression estimation.

Usage

pdc_poisson(X_l, Y_l, f_l, X_u, f_u, intercept = TRUE)

Value

(list): A list containing the following:

est

(vector): vector of PDC Poisson regression coefficient estimates.

se

(vector): vector of standard errors of the coefficients.

Arguments

X_l

(matrix): n x p matrix of covariates in the labeled data.

Y_l

(vector): n-vector of labeled outcomes.

f_l

(vector): n-vector of predictions in the labeled data.

X_u

(matrix): N x p matrix of covariates in the unlabeled data.

f_u

(vector): N-vector of predictions in the unlabeled data.

intercept

(Logical): Do the design matrices include intercept columns? Default is TRUE.

Details

Prediction de-correlated inference: A safe approach for post-prediction inference (Gan et al., 2024) tools:::Rd_expr_doi("10.1111/anzs.12429")

Examples

Run this code

dat <- simdat(model = "poisson")

form <- Y - f ~ X1

X_l <- model.matrix(form, data = dat[dat$set_label == "labeled", ])

Y_l <- dat[dat$set_label == "labeled", all.vars(form)[1]] |>
  matrix(ncol = 1)

f_l <- dat[dat$set_label == "labeled", all.vars(form)[2]] |>
  matrix(ncol = 1)

X_u <- model.matrix(form, data = dat[dat$set_label == "unlabeled", ])

f_u <- dat[dat$set_label == "unlabeled", all.vars(form)[2]] |>
  matrix(ncol = 1)

pdc_poisson(X_l, Y_l, f_l, X_u, f_u, intercept = TRUE)

Run the code above in your browser using DataLab