Computes the weighted least squares estimate of the coefficients.
wls(X, Y, w = NULL, return_se = FALSE)(list): A list containing the following:
(vector): p-vector of weighted least squares estimates of the coefficients.
(vector): If return_se == TRUE, return the p-vector of standard errors of the coefficients.
(matrix): n x p matrix of covariates.
(vector): p-vector of outcome values.
(vector, optional): n-vector of sample weights.
(bool, optional): Whether to return the standard errors of the coefficients.