Learn R Programming

ipd (version 0.4.0)

log1pexp: Log1p Exponential

Description

Computes the natural logarithm of 1 plus the exponential of the input, to handle large inputs.

Usage

log1pexp(x)

Value

(vector): A numeric vector where each element is the result of log(1 + exp(x)).

Arguments

x

(vector): A numeric vector of inputs.