powered by
Computes the natural logarithm of 1 plus the exponential of the input, to handle large inputs.
log1pexp(x)
(vector): A numeric vector where each element is the result of log(1 + exp(x)).
(vector): A numeric vector of inputs.