Computes the statistics needed for the logstic regression-based prediction-powered inference.
logistic_get_stats(
est,
X_l,
Y_l,
f_l,
X_u,
f_u,
w_l = NULL,
w_u = NULL,
use_u = TRUE
)(list): A list containing the following:
(matrix): n x p matrix gradient of the loss function with respect to the coefficients.
(matrix): n x p matrix gradient of the loss function with respect to the coefficients, evaluated using the labeled predictions.
(matrix): N x p matrix gradient of the loss function with respect to the coefficients, evaluated using the unlabeled predictions.
(matrix): p x p matrix inverse Hessian of the loss function with respect to the coefficients.
(vector): Point estimates of the coefficients.
(matrix): Covariates for the labeled data set.
(vector): Labels for the labeled data set.
(vector): Predictions for the labeled data set.
(matrix): Covariates for the unlabeled data set.
(vector): Predictions for the unlabeled data set.
(vector, optional): Sample weights for the labeled data set.
(vector, optional): Sample weights for the unlabeled data set.
(bool, optional): Whether to use the unlabeled data set.