View source: R/postpi_analytic_ols.R
| postpi_analytic_ols | R Documentation |
Helper function for PostPI OLS estimation (analytic correction)
postpi_analytic_ols(X_l, Y_l, f_l, X_u, f_u, original = FALSE)
X_l |
(matrix): n x p matrix of covariates in the labeled data. |
Y_l |
(vector): n-vector of labeled outcomes. |
f_l |
(vector): n-vector of predictions in the labeled data. |
X_u |
(matrix): N x p matrix of covariates in the unlabeled data. |
f_u |
(vector): N-vector of predictions in the unlabeled data. |
original |
(boolean): Logical argument to use original method from Wang et al. (2020). Defaults to FALSE; TRUE retained for posterity. |
Methods for correcting inference based on outcomes predicted by machine learning (Wang et al., 2020) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1073/pnas.2001238117")}
A list of outputs: estimate of the inference model parameters and corresponding standard error estimate.
dat <- simdat(model = "ols")
form <- Y - f ~ X1
X_l <- model.matrix(form, data = dat[dat$set_label == "labeled", ])
Y_l <- dat[dat$set_label == "labeled", all.vars(form)[1]] |>
matrix(ncol = 1)
f_l <- dat[dat$set_label == "labeled", all.vars(form)[2]] |>
matrix(ncol = 1)
X_u <- model.matrix(form, data = dat[dat$set_label == "unlabeled", ])
f_u <- dat[dat$set_label == "unlabeled", all.vars(form)[2]] |>
matrix(ncol = 1)
postpi_analytic_ols(X_l, Y_l, f_l, X_u, f_u)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.